---
-- Name: AID-009 - AI_A2A - Border Test
-- Author: FlightControl
-- Date Created: 06 Aug 2017


-- Define a SET_GROUP object that builds a collection of groups that define the EWR network.
-- Here we build the network with all the groups that have a name starting with DF CCCP AWACS and DF CCCP EWR.
DetectionSetGroup = SET_GROUP:New()
DetectionSetGroup:FilterPrefixes( { "AWACS_Blue", "EWR_Blue" } )
DetectionSetGroup:FilterStart()

Detection = DETECTION_AREAS:New( DetectionSetGroup, 30000 )

-- Setup the A2A dispatcher, and initialize it.
A2ADispatcher = AI_A2A_DISPATCHER:New( Detection )

-- Setup the border zone. 
-- In this case the border is a POLYGON, 
-- which takes the waypoints of a late activated group with the name Blue Border as the boundaries of the border area.
-- Any enemy crossing this border will be engaged.
BlueBorderZone = ZONE_POLYGON:New( "Blue Border", GROUP:FindByName( "Blue Border" ) )
A2ADispatcher:SetBorderZone( BlueBorderZone )

A2ADispatcher:SetTacticalDisplay( false )

A2ADispatcher:SetIntercept( 450 )

-- Setup the squadrons.

A2ADispatcher:SetSquadron( "Incirlik", AIRBASE.Syria.Incirlik, { "SQ Blue F-16" }, 20 )
A2ADispatcher:SetSquadronGci( "Incirlik", 1000, 1500 )
A2ADispatcher:SetSquadronTakeoffFromParkingHot( "Incirlik" )
A2ADispatcher:SetSquadronLandingAtEngineShutdown( "Incirlik" )

A2ADispatcher:SetSquadron( "Gaziantep", AIRBASE.Syria.Gaziantep, { "SQ Blue F-16" }, 5 )
A2ADispatcher:SetSquadronGci( "Gaziantep", 1000, 1500 )
A2ADispatcher:SetSquadronTakeoffFromParkingHot( "Gaziantep" )
A2ADispatcher:SetSquadronLandingAtEngineShutdown( "Gaziantep" )

A2ADispatcher:SetSquadron( "Sanliurfa", AIRBASE.Syria.Sanliurfa, { "SQ Blue F-16" }, 5 )
A2ADispatcher:SetSquadronGci( "Sanliurfa", 1000, 1500 )
A2ADispatcher:SetSquadronTakeoffFromParkingHot( "Sanliurfa" )
A2ADispatcher:SetSquadronLandingAtEngineShutdown( "Sanliurfa" )
